﻿' -----------------------------------------------------------------------------------------
'
' iRobListe.vb                                                      Ulrich Müller  13.06.06
'                                                                   PCS1700 VB 2005 Express
' FishRobot : Listengesteuerter Industry Robot
'             entspricht einem SäulenRobot, der Greifer wird hier nicht berücksichtigt
'             Die RobListe mit den Einzelpositionen wird in iRobDaten.XML gespeichert
' Basis ist die Assembly FishFace2005.DLL
'
' -----------------------------------------------------------------------------------------

Option Explicit On
Option Strict Off
Imports System.Xml.Serialization
Imports FishFace40

Public Class iRobListe

  Dim XMLName As String = New IO.DirectoryInfo(".\").FullName & "iRobDaten.XML"
  Dim ir As iRobDaten
  Dim MotList(,) As Integer = {{1, 180}, {2, 100}, {3, 110}}
  Dim WithEvents ft As New FishRobot(MotList)

  Private Sub Action()
    ' --- Endlosschleife : Die RobPositionen der Liste werden angefahren ---
    '     Ende : ESC-Taste oder HALT-Button
    Dim rp As RobPosition
    Do
      ft.MoveHome()
      For Each rp In ir.RobListe
        ft.MoveTo(rp.Saule, rp.ArmV, rp.ArmH)
      Next
    Loop Until ft.Finish()
  End Sub

#Region "--- ProgramControl ---"
  Private Sub cmdAction_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) _
  Handles cmdAction.Click
    ' --- Open erstes ROBO Interface an USB oder Intelligent Interface an COM ---
    '     während des Ablaufs von Action gesperrt
    Try
      If cboPortName.SelectedIndex = 0 Then
        ft.OpenInterface(IFTypen.ftROBO_first_USB, 0)
      Else
        ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5)
      End If
      cmdAction.Enabled = False
      cmdEnde.Text = "&HALT"
      lblStatus.Text = "--- Bei der Arbeit ---"

      Action()          ' --- Nutz-Routine für die Anwendung

      ft.ClearMotors()
    Catch ex As FishFaceException
      MsgBox(ex.Message)
    Finally
      ft.CloseInterface()
      cmdAction.Enabled = True
      cmdEnde.Text = "&ENDE"
      lblStatus.Text = "--- Auf ein Neues ---"
      cmdEnde.Focus()
    End Try

  End Sub

  Private Sub cmdEnde_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdEnde.Click
    ' --- Programmende nur, wenn Action nicht läuft ---
    If cmdEnde.Text = "&HALT" Then ft.NotHalt = True Else Me.Close()
  End Sub

  Private Sub frmLoad(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    ' --- Deserialisieren der in XMLName gespeicherten Daten, 
    '     einschl. der Liste der RobPositionen
    If IO.File.Exists(XMLName) Then
      Dim ser As New XmlSerializer(GetType(iRobDaten))
      Dim xml As New IO.StreamReader(XMLName, IO.FileMode.Open)
      ir = CType(ser.Deserialize(xml), iRobDaten)
      xml.Close()
    Else
      ir = New iRobDaten()
    End If
    Me.Left = ir.FormLeft
    Me.Top = ir.FormTop
    cboPortName.SelectedIndex = ir.PortNr
  End Sub

  Private Sub frmClosing(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles MyBase.FormClosing
    ' --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ---
    If cmdEnde.Text = "&HALT" Then e.Cancel = True
  End Sub

  Private Sub frmClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs) Handles MyBase.FormClosed
    ' --- Serialisieren der in iRobDaten enthaltenen Daten
    Dim ser As New XmlSerializer(GetType(iRobDaten))
    Dim xml As New IO.StreamWriter(XMLName)
    ir.FormLeft = Me.Left
    ir.FormTop = Me.Top
    ir.PortNr = cboPortName.SelectedIndex
    ser.Serialize(xml, ir)
    xml.Close()
  End Sub

#End Region

  Private Sub ft_PositionChange(ByVal sender As Object, ByVal ActPositions() As Integer) _
  Handles ft.PositionChange
    ' --- Anzeige der aktuellen Position (Impulse ab Home) ---
    lblPosition.Text = ActPositions(0) & " - " & ActPositions(1) & " - " & ActPositions(2)
  End Sub
End Class
